searchNodes=[{"doc":"The ExTorch namespace contains data structures for multi-dimensional tensors and mathematical operations over these are defined. Additionally, it provides many utilities for efficient serializing of Tensors and arbitrary types, and other useful utilities. It has a CUDA counterpart, that enables you to run your tensor computations on an NVIDIA GPU with compute capability &gt;= 3.0","ref":"ExTorch.html","title":"ExTorch","type":"module"},{"doc":"See ExTorch.arange/4 Available signature calls: arange(end_bound)","ref":"ExTorch.html#arange/1","title":"ExTorch.arange/1","type":"function"},{"doc":"See ExTorch.arange/4 Available signature calls: arange(start, end_bound) arange(end_bound, kwargs)","ref":"ExTorch.html#arange/2","title":"ExTorch.arange/2","type":"function"},{"doc":"See ExTorch.arange/4 Available signature calls: arange(start, end_bound, step) arange(start, end_bound, kwargs) arange(end_bound, step, opts)","ref":"ExTorch.html#arange/3","title":"ExTorch.arange/3","type":"function"},{"doc":"Returns a 1-D tensor of size $\\left\\lceil \\frac{\\text{end} - \\text{start}}{\\text{step}} \\right\\rceil$ with values from the interval [start, end) taken with common difference step beginning from start . Note that non-integer step is subject to floating point rounding errors when comparing against end ; to avoid inconsistency, we advise adding a small epsilon to end in such cases. $$out_{i + 1} = out_i + step$$ Arguments start : the starting value for the set of points. Default: 0 . end : the ending value for the set of points. step : the gap between each pair of adjacent points. Default: 1 . Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples # Single argument, end only iex&gt; ExTorch . arange ( 5 ) # Tensor &lt; 0 1 2 3 4 [ CPUFloatType { 5 } ] &gt; # End only with options iex&gt; ExTorch . arange ( 5 , dtype : :uint8 ) #Tensor&lt; 0 1 2 3 4 [ CPUByteType { 5 } ] # Start to end iex&gt; ExTorch . arange ( 1 , 7 ) # Tensor &lt; 1 2 3 4 5 6 [ CPUFloatType { 6 } ] &gt; # Start to end with options iex&gt; ExTorch . arange ( 1 , 7 , device : :cpu , dtype : :float64 ) # Tensor &lt; 1 2 3 4 5 6 [ CPUDoubleType { 6 } ] &gt; # Start to end with step iex&gt; ExTorch . arange ( - 1.3 , 2.4 , 0.5 ) # Tensor &lt; - 1.3000 - 0.8000 - 0.3000 0.2000 0.7000 1.2000 1.7000 2.2000 [ CPUFloatType { 8 } ] &gt; # Start to end with step and options iex&gt; ExTorch . arange ( - 1.3 , 2.4 , 0.5 , dtype : :float64 ) # Tensor &lt; - 1.3000 - 0.8000 - 0.3000 0.2000 0.7000 1.2000 1.7000 2.2000 [ CPUDoubleType { 8 } ] &gt;","ref":"ExTorch.html#arange/4","title":"ExTorch.arange/4","type":"function"},{"doc":"See ExTorch.empty/2 Available signature calls: empty(size)","ref":"ExTorch.html#empty/1","title":"ExTorch.empty/1","type":"function"},{"doc":"Returns a tensor filled with uninitialized data. The shape of the tensor is defined by the tuple argument size . Arguments size : a tuple/list of integers defining the shape of the output tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . empty ( { 2 , 3 } ) # Tensor &lt; - 6.2093 e + 29 4.5611e-41 0.0000 e + 00 0.0000 e + 00 1.1673e-42 0.0000 e + 00 [ CPUFloatType { 2 , 3 } ] &gt; iex&gt; ExTorch . empty ( { 2 , 3 } , dtype : :int64 , device : :cpu ) # Tensor &lt; 1.4023 e + 14 0.0000 e + 00 0.0000 e + 00 1.0000 e + 00 7.0000 e + 00 1.4023 e + 14 [ CPULongType { 2 , 3 } ] &gt;","ref":"ExTorch.html#empty/2","title":"ExTorch.empty/2","type":"function"},{"doc":"See ExTorch.eye/3 Available signature calls: eye(n)","ref":"ExTorch.html#eye/1","title":"ExTorch.eye/1","type":"function"},{"doc":"See ExTorch.eye/3 Available signature calls: eye(n, m) eye(n, kwargs)","ref":"ExTorch.html#eye/2","title":"ExTorch.eye/2","type":"function"},{"doc":"Returns a 2-D tensor with ones on the diagonal and zeros elsewhere. Arguments n : the number of rows m : the number of columns Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . eye ( 3 , 3 ) # Tensor &lt; 1 0 0 0 1 0 0 0 1 [ CPUFloatType { 3 , 3 } ] &gt; iex&gt; ExTorch . eye ( 4 , 6 , dtype : :uint8 , device : :cpu ) # Tensor &lt; 1 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 [ CPUByteType { 4 , 6 } ] &gt;","ref":"ExTorch.html#eye/3","title":"ExTorch.eye/3","type":"function"},{"doc":"See ExTorch.full/3 Available signature calls: full(size, scalar)","ref":"ExTorch.html#full/2","title":"ExTorch.full/2","type":"function"},{"doc":"Returns a tensor filled with the scalar value scalar , with the shape defined by the variable argument size . Arguments size : a tuple/list of integers defining the shape of the output tensor. scalar : the value to fill the output tensor with. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . full ( { 2 , 3 } , 2 ) # Tensor &lt; 2 2 2 2 2 2 [ CPUFloatType { 2 , 3 } ] &gt; iex&gt; ExTorch . full ( { 2 , 3 } , 23 , dtype : :uint8 , device : :cpu ) # Tensor &lt; 23 23 23 23 23 23 [ CPUByteType { 2 , 3 } ] &gt; iex&gt; ExTorch . full ( { 2 , 3 } , 3.1416 ) # Tensor &lt; 3.1416 3.1416 3.1416 3.1416 3.1416 3.1416 [ CPUFloatType { 5 } ] &gt;","ref":"ExTorch.html#full/3","title":"ExTorch.full/3","type":"function"},{"doc":"Index a tensor given a list of integers, ranges, tensors, nil or :ellipsis . Arguments tensor : Input tensor ( ExTorch.Tensor ) indices : Indices to select ( ExTorch.Index ) Examples iex&gt; a = ExTorch . rand ( { 3 , 4 , 4 } ) # Tensor &lt; ( 1 , . , . ) = 0.8974 0.6348 0.4760 0.0726 0.3809 0.4332 0.9761 0.4656 0.8544 0.0605 0.1683 0.4142 0.7736 0.1794 0.2732 0.3165 ( 2 , . , . ) = 0.1967 0.2013 0.7938 0.8738 0.0240 0.0098 0.4605 0.3970 0.9699 0.1057 0.3176 0.2651 0.7698 0.6383 0.0016 0.7198 ( 3 , . , . ) = 0.5061 0.0021 0.4804 0.7444 0.5725 0.2019 0.3524 0.5345 0.3876 0.3622 0.5318 0.0445 0.3276 0.2913 0.8069 0.6132 [ CPUDoubleType { 3 , 4 , 4 } ] &gt; # Use an integer index iex&gt; ExTorch . index ( a , 0 ) # Tensor &lt; 0.8974 0.6348 0.4760 0.0726 0.3809 0.4332 0.9761 0.4656 0.8544 0.0605 0.1683 0.4142 0.7736 0.1794 0.2732 0.3165 [ CPUDoubleType { 4 , 4 } ] &gt; # Use a slice index iex&gt; ExTorch . index ( a , 0 .. 2 ) # Tensor &lt; ( 1 , . , . ) = 0.8974 0.6348 0.4760 0.0726 0.3809 0.4332 0.9761 0.4656 0.8544 0.0605 0.1683 0.4142 0.7736 0.1794 0.2732 0.3165 ( 2 , . , . ) = 0.1967 0.2013 0.7938 0.8738 0.0240 0.0098 0.4605 0.3970 0.9699 0.1057 0.3176 0.2651 0.7698 0.6383 0.0016 0.7198 [ CPUDoubleType { 2 , 4 , 4 } ] &gt; iex&gt; ExTorch . index ( a , ExTorch . slice ( 0 , 1 ) ) # Tensor &lt; ( 1 , . , . ) = 0.8974 0.6348 0.4760 0.0726 0.3809 0.4332 0.9761 0.4656 0.8544 0.0605 0.1683 0.4142 0.7736 0.1794 0.2732 0.3165 [ CPUDoubleType { 1 , 4 , 4 } ] &gt; # Index multiple dimensions iex&gt; ExTorch . index ( a , [ ::: , ExTorch . slice ( 0 , 2 ) , 0 ] ) # Tensor &lt; 0.8974 0.3809 0.1967 0.0240 0.5061 0.5725 [ CPUDoubleType { 3 , 2 } ] &gt; Notes For more information regarding the kind of accepted indices and their corresponding behaviour, please see the ExTorch.Index documentation","ref":"ExTorch.html#index/2","title":"ExTorch.index/2","type":"function"},{"doc":"See ExTorch.linspace/4 Available signature calls: linspace(start, end_bound, steps)","ref":"ExTorch.html#linspace/3","title":"ExTorch.linspace/3","type":"function"},{"doc":"Creates a one-dimensional tensor of size steps whose values are evenly spaced from start to end , inclusive. That is, the value are: $$(\\text{start}, \\text{start} + \\frac{\\text{end} - \\text{start}}{\\text{steps} - 1}, \\ldots, \\text{start} + (\\text{steps} - 2) * \\frac{\\text{end} - \\text{start}}{\\text{steps} - 1}, \\text{end})$$ Arguments start : the starting value for the set of points. end : the ending value for the set of points. steps : size of the constructed tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples # Returns a tensor with 10 evenly-spaced values between -2 and 10 iex&gt; ExTorch . linspace ( - 2 , 10 , 10 ) # Tensor &lt; - 2.0000 - 0.6667 0.6667 2.0000 3.3333 4.6667 6.0000 7.3333 8.6667 10.0000 [ CPUFloatType { 10 } ] &gt; # Returns a tensor with 10 evenly-spaced int32 values between -2 and 10 iex&gt; ExTorch . linspace ( - 2 , 10 , 10 , dtype : :int32 ) # Tensor &lt; - 2 0 0 1 3 4 6 7 8 10 [ CPUIntType { 10 } ] &gt;","ref":"ExTorch.html#linspace/4","title":"ExTorch.linspace/4","type":"function"},{"doc":"See ExTorch.logspace/5 Available signature calls: logspace(start, end_bound, steps)","ref":"ExTorch.html#logspace/3","title":"ExTorch.logspace/3","type":"function"},{"doc":"See ExTorch.logspace/5 Available signature calls: logspace(start, end_bound, steps, kwargs) logspace(start, end_bound, steps, base)","ref":"ExTorch.html#logspace/4","title":"ExTorch.logspace/4","type":"function"},{"doc":"Creates a one-dimensional tensor of size steps whose values are evenly spaced from ${{\\text{{base}}}}^{{\\text{{start}}}}$ to ${{\\text{{base}}}}^{{\\text{{end}}}}$, inclusive, on a logarithmic scale with base base . That is, the values are: $$(\\text{base}^{\\text{start}}, \\text{base}^{(\\text{start} + \\frac{\\text{end} - \\text{start}}{ \\text{steps} - 1})}, \\ldots, \\text{base}^{(\\text{start} + (\\text{steps} - 2) * \\frac{\\text{end} - \\text{start}}{ \\text{steps} - 1})}, \\text{base}^{\\text{end}})$$ Arguments start : the starting value for the set of points. end : the ending value for the set of points. steps : size of the constructed tensor. base : base of the logarithm function. Default: 10.0 . Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . logspace ( - 10 , 10 , 5 ) # Tensor &lt; 1.0000e-10 1.0000e-05 1.0000 e + 00 1.0000 e + 05 1.0000 e + 10 [ CPUFloatType { 5 } ] &gt; iex&gt; ExTorch . logspace ( 0.1 , 1.0 , 5 ) # Tensor &lt; 1.2589 2.1135 3.5481 5.9566 10.0000 [ CPUFloatType { 5 } ] &gt; iex&gt; ExTorch . logspace ( 0.1 , 1.0 , 3 , base : 2 ) # Tensor &lt; 1.0718 1.4641 2.0000 [ CPUFloatType { 3 } ] &gt; iex&gt; ExTorch . logspace ( 0.1 , 1.0 , 3 , base : 2 , dtype : :float64 ) # Tensor &lt; 1.0718 1.4641 2.0000 [ CPUDoubleType { 3 } ] &gt;","ref":"ExTorch.html#logspace/5","title":"ExTorch.logspace/5","type":"function"},{"doc":"See ExTorch.ones/2 Available signature calls: ones(size)","ref":"ExTorch.html#ones/1","title":"ExTorch.ones/1","type":"function"},{"doc":"Returns a tensor filled with the scalar value 1 , with the shape defined by the variable argument size . Arguments size : a tuple/list of integers defining the shape of the output tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . ones ( { 2 , 3 } ) # Tensor &lt; 1 1 1 1 1 1 [ CPUFloatType { 2 , 3 } ] &gt; iex&gt; ExTorch . ones ( { 2 , 3 } , dtype : :uint8 , device : :cpu ) # Tensor &lt; 1 1 1 1 1 1 [ CPUByteType { 2 , 3 } ] &gt; iex&gt; ExTorch . ones ( { 5 } ) # Tensor &lt; 1 1 1 1 1 [ CPUFloatType { 5 } ] &gt;","ref":"ExTorch.html#ones/2","title":"ExTorch.ones/2","type":"function"},{"doc":"See ExTorch.rand/2 Available signature calls: rand(size)","ref":"ExTorch.html#rand/1","title":"ExTorch.rand/1","type":"function"},{"doc":"Returns a tensor filled with random numbers from a uniform distribution on the interval $[0, 1)$ The shape of the tensor is defined by the variable argument size . Arguments size : a tuple/list of integers defining the shape of the output tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . rand ( { 3 , 3 , 3 } ) # Tensor &lt; ( 1 , . , . ) = 0.5997 0.3569 0.7639 0.1939 0.0923 0.0942 0.3355 0.3534 0.6490 ( 2 , . , . ) = 0.7250 0.5877 0.9215 0.1583 0.7270 0.3289 0.7083 0.1259 0.0050 ( 3 , . , . ) = 0.1731 0.9534 0.6758 0.8523 0.0659 0.3623 0.0747 0.6079 0.7227 [ CPUFloatType { 3 , 3 , 3 } ] &gt; iex&gt; ExTorch . rand ( { 2 , 3 } , dtype : :float64 ) # Tensor &lt; 0.6012 0.6164 0.2413 0.9720 0.7804 0.4863 [ CPUDoubleType { 2 , 3 } ] &gt;","ref":"ExTorch.html#rand/2","title":"ExTorch.rand/2","type":"function"},{"doc":"See ExTorch.randint/4 Available signature calls: randint(high, size)","ref":"ExTorch.html#randint/2","title":"ExTorch.randint/2","type":"function"},{"doc":"See ExTorch.randint/4 Available signature calls: randint(low, high, size) randint(high, size, opts) randint(high, size, kwargs)","ref":"ExTorch.html#randint/3","title":"ExTorch.randint/3","type":"function"},{"doc":"Returns a tensor filled with random integers generated uniformly between low (inclusive) and high (exclusive). The shape of the tensor is defined by the variable argument size . Arguments low : Lowest integer to be drawn from the distribution. Default: 0 . high : One above the highest integer to be drawn from the distribution. size : a tuple/list of integers defining the shape of the output tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples # Sample numbers between 0 and 3 iex&gt; ExTorch . randint ( 3 , { 3 , 3 , 4 } ) # Tensor &lt; ( 1 , . , . ) = 2 2 0 2 0 0 1 0 1 2 1 0 ( 2 , . , . ) = 1 1 2 0 0 2 1 2 2 0 0 1 ( 3 , . , . ) = 0 2 0 2 0 1 1 1 2 1 1 1 [ CPUFloatType { 3 , 3 , 4 } ] &gt; # Sample numbers between 0 and 3 of type int64 iex&gt; ExTorch . randint ( 3 , { 3 , 3 , 4 } , dtype : :int64 ) # Tensor &lt; ( 1 , . , . ) = 2 2 1 0 0 1 0 1 2 2 2 2 ( 2 , . , . ) = 1 1 1 1 1 1 0 1 2 1 0 2 ( 3 , . , . ) = 1 2 1 0 1 1 2 1 1 1 0 1 [ CPULongType { 3 , 3 , 4 } ] &gt; # Sample numbers between -2 and 4 iex&gt; ExTorch . randint ( - 2 , 3 , { 2 , 2 , 4 } ) # Tensor &lt; ( 1 , . , . ) = - 2 2 0 - 2 0 2 1 2 ( 2 , . , . ) = - 2 - 1 - 1 1 0 - 1 0 0 [ CPUFloatType { 2 , 2 , 4 } ] &gt; # Sample numbers between -2 and 4 on cpu iex&gt; ExTorch . randint ( - 2 , 3 , { 2 , 2 , 4 } , device : :cpu ) # Tensor &lt; ( 1 , . , . ) = - 2 0 0 - 2 2 1 2 - 2 ( 2 , . , . ) = 2 - 1 - 1 1 1 2 1 - 2 [ CPUFloatType { 2 , 2 , 4 } ] &gt;","ref":"ExTorch.html#randint/4","title":"ExTorch.randint/4","type":"function"},{"doc":"See ExTorch.randn/2 Available signature calls: randn(size)","ref":"ExTorch.html#randn/1","title":"ExTorch.randn/1","type":"function"},{"doc":"Returns a tensor filled with random numbers from a normal distribution with mean 0 and variance 1 (also called the standard normal distribution). $$\\text{{out}}_{{i}} \\sim \\mathcal{{N}}(0, 1)$$ The shape of the tensor is defined by the variable argument :attr: size . Arguments size : a tuple/list of integers defining the shape of the output tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . randn ( { 3 , 3 , 5 } ) #Tensor&lt; ( 1 , . , . ) = 0.0784 - 0.3355 - 0.0159 - 0.0606 - 1.2691 - 0.6146 0.2346 0.8563 0.8795 0.0645 - 1.9992 0.6692 0.2269 1.9263 0.1033 ( 2 , . , . ) = 0.2647 0.7078 0.0270 - 1.1330 - 0.4143 1.2061 - 1.1191 0.7465 0.2140 0.7406 0.3587 - 0.6102 0.3359 - 0.4517 - 0.5276 ( 3 , . , . ) = 1.7122 0.3814 - 0.6218 0.8047 - 0.6067 0.1693 0.4957 - 0.6139 0.7341 1.4272 0.1630 - 0.1142 0.8823 0.8026 1.3355 [ CPUFloatType { 3 , 3 , 5 } ] iex&gt; ExTorch . randn ( { 3 , 3 , 5 } , device : :cpu ) # Tensor &lt; ( 1 , . , . ) = - 0.8990 - 0.3449 - 1.2916 - 0.0318 0.7116 0.9068 - 0.3159 - 0.6416 - 1.8414 - 0.1421 - 0.9251 - 0.8209 0.0830 - 2.5484 0.3731 ( 2 , . , . ) = 0.5975 0.0690 - 0.2972 - 0.0328 - 0.2672 1.3053 0.7803 - 0.1992 - 2.1078 - 0.7520 1.3048 0.6391 0.1137 2.0412 0.2380 ( 3 , . , . ) = - 1.1820 - 1.9329 - 0.3965 - 0.0618 - 1.1190 0.7926 - 1.8551 1.1356 - 0.7451 - 0.6003 1.0266 0.5791 0.2724 0.6952 - 3.1296 [ CPUFloatType { 3 , 3 , 5 } ] &gt;","ref":"ExTorch.html#randn/2","title":"ExTorch.randn/2","type":"function"},{"doc":"Create a slice to index a tensor. Arguments start : The starting slice value. Default: nil stop : The non-inclusive end of the slice. Default: nil step : The step between values. Default: nil Returns slice : An ExTorch.Index.Slice struct that represents the slice. Notes An empty slice will represent the &quot;take-all axis&quot;, represented by &quot;:&quot; in Python.","ref":"ExTorch.html#slice/3","title":"ExTorch.slice/3","type":"function"},{"doc":"See ExTorch.tensor/2 Available signature calls: tensor(list)","ref":"ExTorch.html#tensor/1","title":"ExTorch.tensor/1","type":"function"},{"doc":"Constructs a tensor with data. Arguments list : Initial data for the tensor. Can be a list, tuple or number. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . tensor ( [ [ 0.1 , 1.2 ] , [ 2.2 , 3.1 ] , [ 4.9 , 5.2 ] ] ) # Tensor &lt; 0.1000 1.2000 2.2000 3.1000 4.9000 5.2000 [ CPUFloatType { 3 , 2 } ] &gt; # Type inference iex&gt; ExTorch . tensor ( [ 0 , 1 ] ) # Tensor &lt; 0 1 [ CPUByteType { 2 } ] &gt; iex&gt; ExTorch . tensor ( [ [ 0.11111 , 0.222222 , 0.3333333 ] ] , dtype : :float64 ) # Tensor &lt; 0.1111 0.2222 0.3333 [ CPUDoubleType { 1 , 3 } ] &gt;","ref":"ExTorch.html#tensor/2","title":"ExTorch.tensor/2","type":"function"},{"doc":"Append an empty dimension to a tensor on a given dimension. Arguments tensor : Input tensor ( ExTorch.Tensor ) dim : Dimension ( integer() )","ref":"ExTorch.html#unsqueeze/2","title":"ExTorch.unsqueeze/2","type":"function"},{"doc":"See ExTorch.zeros/2 Available signature calls: zeros(size)","ref":"ExTorch.html#zeros/1","title":"ExTorch.zeros/1","type":"function"},{"doc":"Returns a tensor filled with the scalar value 0 , with the shape defined by the variable argument size . Arguments size : a tuple/list of integers defining the shape of the output tensor. Keyword args dtype ( ExTorch.DType , optional): the desired data type of returned tensor. Default : if nil , uses a global default (see ExTorch.set_default_tensor_type ). layout ( ExTorch.Layout , optional): the desired layout of returned Tensor. Default : :strided . device ( ExTorch.Device , optional): the desired device of returned tensor. Default: if nil , uses the current device for the default tensor type (see ExTorch.set_default_tensor_type ). device will be the CPU for CPU tensor types and the current CUDA device for CUDA tensor types. requires_grad ( boolean() , optional): If autograd should record operations on the returned tensor. Default : false . pin_memory ( bool , optional): If set, returned tensor would be allocated in the pinned memory. Works only for CPU tensors. Default: false . memory_format ( ExTorch.MemoryFormat , optional): the desired memory format of returned Tensor. Default : :contiguous Examples iex&gt; ExTorch . zeros ( { 2 , 3 } ) # Tensor &lt; 0 0 0 0 0 0 [ CPUFloatType { 2 , 3 } ] &gt; iex&gt; ExTorch . zeros ( { 2 , 3 } , dtype : :uint8 , device : :cpu ) # Tensor &lt; 0 0 0 0 0 0 [ CPUByteType { 2 , 3 } ] &gt; iex&gt; ExTorch . zeros ( { 5 } ) # Tensor &lt; 0 0 0 0 0 [ CPUFloatType { 5 } ] &gt;","ref":"ExTorch.html#zeros/2","title":"ExTorch.zeros/2","type":"function"},{"doc":"A torch.dtype is an object that represents the data type of a torch.Tensor . ExTorch has twelve different data types:","ref":"ExTorch.DType.html","title":"ExTorch.DType","type":"module"},{"doc":"","ref":"ExTorch.DType.html#is_dtype/1","title":"ExTorch.DType.is_dtype/1","type":"macro"},{"doc":"Alias names to other integral/floating tensor types.","ref":"ExTorch.DType.html#t:alias_type/0","title":"ExTorch.DType.alias_type/0","type":"type"},{"doc":"Basic tensor types","ref":"ExTorch.DType.html#t:base_type/0","title":"ExTorch.DType.base_type/0","type":"type"},{"doc":"Complex number tensor types.","ref":"ExTorch.DType.html#t:complex_type/0","title":"ExTorch.DType.complex_type/0","type":"type"},{"doc":"A torch.dtype is an object that represents the data type of a torch.Tensor.","ref":"ExTorch.DType.html#t:dtype/0","title":"ExTorch.DType.dtype/0","type":"type"},{"doc":"Floating point tensor types.","ref":"ExTorch.DType.html#t:floating_type/0","title":"ExTorch.DType.floating_type/0","type":"type"},{"doc":"Integral tensor types, unsigned and signed.","ref":"ExTorch.DType.html#t:integral_type/0","title":"ExTorch.DType.integral_type/0","type":"type"},{"doc":"Numeric tensor types","ref":"ExTorch.DType.html#t:numeric_type/0","title":"ExTorch.DType.numeric_type/0","type":"type"},{"doc":"Quantized floating point tensor types.","ref":"ExTorch.DType.html#t:quantized_type/0","title":"ExTorch.DType.quantized_type/0","type":"type"},{"doc":"Public API documentation for DelegateWithDocs . This module is based on https://github.com/danielberkompas/delegate_with_docs","ref":"ExTorch.DelegateWithDocs.html","title":"ExTorch.DelegateWithDocs","type":"module"},{"doc":"Overrides Kernel.defdelegate/2 with defdelegate/2 .","ref":"ExTorch.DelegateWithDocs.html#__using__/1","title":"ExTorch.DelegateWithDocs.__using__/1","type":"macro"},{"doc":"Delegates a function to another module, copying its docs. Use exactly like Kernel.defdelegate/2 .","ref":"ExTorch.DelegateWithDocs.html#defdelegate/2","title":"ExTorch.DelegateWithDocs.defdelegate/2","type":"macro"},{"doc":"Get the doc string for a given module and function. Example DelegateWithDocs . get_doc ( MyModule.Internal , { :my_func , 2 } )","ref":"ExTorch.DelegateWithDocs.html#get_doc/2","title":"ExTorch.DelegateWithDocs.get_doc/2","type":"function"},{"doc":"Get the typespecs for a given function as an AST.","ref":"ExTorch.DelegateWithDocs.html#get_specs/2","title":"ExTorch.DelegateWithDocs.get_specs/2","type":"function"},{"doc":"A torch.device is an object representing the device on which a torch.Tensor is or will be allocated. The torch.device contains a device type ('cpu' or 'cuda') and optional device ordinal for the device type. If the device ordinal is not present, this object will always represent the current device for the device type, even after torch.cuda.set_device() is called; e.g., a torch.Tensor constructed with device 'cuda' is equivalent to 'cuda:X' where X is the result of torch.cuda.current_device() . A torch.Tensor’s device can be accessed via the Tensor.device property. A torch.device can be constructed via a string or via a string and device ordinal","ref":"ExTorch.Device.html","title":"ExTorch.Device","type":"module"},{"doc":"","ref":"ExTorch.Device.html#is_device/1","title":"ExTorch.Device.is_device/1","type":"macro"},{"doc":"This object will always represent the current device for the device type","ref":"ExTorch.Device.html#t:atomic_device/0","title":"ExTorch.Device.atomic_device/0","type":"type"},{"doc":"The torch.device contains a device type ('cpu' or 'cuda') and optional device ordinal for the device type","ref":"ExTorch.Device.html#t:composed_device/0","title":"ExTorch.Device.composed_device/0","type":"type"},{"doc":"A torch.device is an object representing the device on which a torch.Tensor is or will be allocated. The torch.device argument in functions can generally be substituted with a string. This allows for fast prototyping of code.","ref":"ExTorch.Device.html#t:device/0","title":"ExTorch.Device.device/0","type":"type"},{"doc":"An index is an object that can act as an accessor to a ExTorch.Tensor . ExTorch has five kinds of indices:","ref":"ExTorch.Index.html","title":"ExTorch.Index","type":"module"},{"doc":"An actual index element, after aliases are interpreted.","ref":"ExTorch.Index.html#t:actual_index/0","title":"ExTorch.Index.actual_index/0","type":"type"},{"doc":"Dimension appending/removing indices. Description nil - Adds an empty dimension on the specified position. true - Same as nil false - Adds a zero dimension on the specified position.","ref":"ExTorch.Index.html#t:dim_modifier_index/0","title":"ExTorch.Index.dim_modifier_index/0","type":"type"},{"doc":"Skip dimensions in between other ones. Notes Ellipsis indices will behave as a sequence of empty ExTorch.Index.Slice s between the dimensions that are specified. e.g., a = ExTorch . empty ( { 3 , 4 , 5 , 6 } ) # Indexing will yield a tensor of size {4, 5} indexing = ExTorch . index ( a , [ 0 , :... , 1 ] )","ref":"ExTorch.Index.html#t:ellipsis_index/0","title":"ExTorch.Index.ellipsis_index/0","type":"type"},{"doc":"An individual index element.","ref":"ExTorch.Index.html#t:index/0","title":"ExTorch.Index.index/0","type":"type"},{"doc":"Access a tensor given a particular integer index.","ref":"ExTorch.Index.html#t:integer_index/0","title":"ExTorch.Index.integer_index/0","type":"type"},{"doc":"","ref":"ExTorch.Index.html#t:integer_list/0","title":"ExTorch.Index.integer_list/0","type":"type"},{"doc":"Access a slice of elements in the tensor given a range. Description start..end//step - A standard Elixir range struct, it will be non-inclusive on end , as opposed to its usual behaviour in Elixir. Slice.t() - See ExTorch.Index.Slice ::: - Same as invoking ExTorch.slice/0 .","ref":"ExTorch.Index.html#t:range_index/0","title":"ExTorch.Index.range_index/0","type":"type"},{"doc":"A complete possible index. It can be either a puntual index or a list of puntual indices.","ref":"ExTorch.Index.html#t:t/0","title":"ExTorch.Index.t/0","type":"type"},{"doc":"Access a tensor given another tensor or a list of integers.","ref":"ExTorch.Index.html#t:tensor_list_index/0","title":"ExTorch.Index.tensor_list_index/0","type":"type"},{"doc":"Slice index definition.","ref":"ExTorch.Index.Slice.html","title":"ExTorch.Index.Slice","type":"module"},{"doc":"An ExTorch.Index.Slice is a struct that represents an indexing slice with a start, stop and a number of steps between values.","ref":"ExTorch.Index.Slice.html#t:t/0","title":"ExTorch.Index.Slice.t/0","type":"type"},{"doc":"A torch.layout is an object that represents the memory layout of a torch.Tensor . Currently, we support torch.strided (dense Tensors) and have beta support for torch.sparse_coo (sparse COO Tensors). torch.strided represents dense Tensors and is the memory layout that is most commonly used. Each strided tensor has an associated torch.Storage , which holds its data. These tensors provide multi-dimensional, strided view of a storage. Strides are a list of integers: the k-th stride represents the jump in the memory necessary to go from one element to the next one in the k-th dimension of the Tensor. This concept makes it possible to perform many tensor operations efficiently.","ref":"ExTorch.Layout.html","title":"ExTorch.Layout","type":"module"},{"doc":"","ref":"ExTorch.Layout.html#is_layout/1","title":"ExTorch.Layout.is_layout/1","type":"macro"},{"doc":"A torch.layout is an object that represents the memory layout of a torch.Tensor .","ref":"ExTorch.Layout.html#t:layout/0","title":"ExTorch.Layout.layout/0","type":"type"},{"doc":"A torch.memory_format is an object representing the memory format on which a torch.Tensor is or will be allocated. Possible values are: :contiguous : Tensor is or will be allocated in dense non-overlapping memory. Strides represented by values in decreasing order. :channels_last : Tensor is or will be allocated in dense non-overlapping memory. Strides represented by values in strides[0] &gt; strides[2] &gt; strides[3] &gt; strides[1] == 1 aka NHWC order. :preserve_format : Used in functions like clone to preserve the memory format of the input tensor. If input tensor is allocated in dense non-overlapping memory, the output tensor strides will be copied from the input. Otherwise output strides will follow contiguous","ref":"ExTorch.MemoryFormat.html","title":"ExTorch.MemoryFormat","type":"module"},{"doc":"","ref":"ExTorch.MemoryFormat.html#is_memory_format/1","title":"ExTorch.MemoryFormat.is_memory_format/1","type":"macro"},{"doc":"A torch.memory_format is an object representing the memory format on which a torch.Tensor is or will be allocated.","ref":"ExTorch.MemoryFormat.html#t:memory_format/0","title":"ExTorch.MemoryFormat.memory_format/0","type":"type"},{"doc":"Utilities used to define a module mixin that inherits documentation and specs.","ref":"ExTorch.ModuleMixin.html","title":"ExTorch.ModuleMixin","type":"module"},{"doc":"This macro enables a module to import the functions from another module and expose them as they were defined on it. defmodule BaseModule do def call1 ( arg1 , arg2 ) do arg1 + arg2 end def call2 ( ) do :ok end end defmodule Mixin do import ExTorch.ModuleMixin extends ( BaseModule ) end By using the extends/1 macro, the Mixin module will have the definitions of call1/2 and call2/0 . Implementation notes The function definitions are given via defdelegate internally.","ref":"ExTorch.ModuleMixin.html#extends/1","title":"ExTorch.ModuleMixin.extends/1","type":"macro"},{"doc":"The ExTorch.Native module contains all NIF declarations to call libtorch in C++. All the declarations contained here are placeholder to native calls generated with Rustler and implemented via Rust. Argument optional function declarations with default values are provided on the ExTorch module.","ref":"ExTorch.Native.html","title":"ExTorch.Native","type":"module"},{"doc":"","ref":"ExTorch.Native.html#add/2","title":"ExTorch.Native.add/2","type":"function"},{"doc":"","ref":"ExTorch.Native.html#compilation_info/0","title":"ExTorch.Native.compilation_info/0","type":"function"},{"doc":"Conveniences for declaring native calls to a library in Rustler. This module can be use -d into a module in order to declare a set of native functions: defmodule NativeCalls do use ExTorch.Native.BindingDeclaration defbindings ( :doc_section ) do @doc &quot;&quot;&quot; Get the size of a tensor. ## Arguments - `tensor`: Input tensor &quot;&quot;&quot; @spec size ( ExTorch.Tensor . t ( ) ) :: tuple ( ) defbinding ( size ( tensor ) ) end end Binding behaviour Internally, ExTorch.Native.BindingDeclaration implements the following macros: __using__/0 : Enables the module to be used on a module that uses Rustler in order to define the stub definitions for the native functions to call. defmodule NativeExtension do use NativeCalls use Rustler , otp_app : :app_name , crate : &quot;crate_name&quot; end","ref":"ExTorch.Native.BindingDeclaration.html","title":"ExTorch.Native.BindingDeclaration","type":"module"},{"doc":"General purpose macros to automatically generate binding declarations and calls for both ExTorch callable functions and Rustler signature calls to the NIF library.","ref":"ExTorch.Native.Macros.html","title":"ExTorch.Native.Macros","type":"module"},{"doc":"Automatic binding generation. This macro allows to define a bindings block under a given doc_section for a given set of function bindings. All binding declarations should be signaled using the defbinding function, which recieves the function signature, alongside an optional keyword list of parameter transformations that must be done before calling the native function (defined in ExTorch.Native ). Each defbinding declaration must declare its @spec and optionally its docstring @doc before the call. Additionally, the function binding signature can declare optional arguments. For example: # All function docstrings will be collected under :doc_section_name defbindings ( :doc_section_name ) do @doc &quot;&quot;&quot; The docstring for func goes here &quot;&quot;&quot; @spec func ( type_1 ( ) , type_2 ( ) , type_3 ( ) ) :: ret_type ( ) defbinding ( func ( arg1 , # Positional argument arg2 \\\\ optional_value , # Optional argument arg3 \\\\ optional_value # Optional argument ) ) @doc &quot;&quot;&quot; The docstring for func2 goes here &quot;&quot;&quot; @spec func2 ( type_1 ( ) , type_2 ( ) , type_3 ( ) , type_4 ( ) ) :: ret_type ( ) defbinding ( func2 ( arg1 \\\\ optional_value , # Positional argument with optional value arg2 , # Positional argument arg3 \\\\ optional_value , # Optional argument arg4 \\\\ optional_value # Optional argument ) ) @doc &quot;&quot;&quot; The docstring for func3 goes here &quot;&quot;&quot; @spec func3 ( type_1 ( ) , type_2 ( ) , type_3 ( ) , type_4 ( ) ) :: ret_type ( ) defbinding ( func3 ( arg1 , # Positional argument arg2 , # Positional argument arg3 \\\\ optional_value , # Optional argument arg4 \\\\ optional_value # Optional argument ) , arg1 : arg1 [ :value ] , arg3 : call_to_some_transform ( arg3 , arg2 ) , ) end In case optional arguments are defined, the macro will expand the declaration to allow optional arguments to be passed as a keyword list. For example, the function func will be expanded to the following function calls: func(arg1) , func(arg1, kwargs) , func(arg1, arg2) , func(arg1, arg2, kwargs) and func(arg1, arg2, arg3) , where kwargs correspond to arg2: value, arg3: value2 and arg3: value , respectively. When the first argument is declared as optional, the macro will generate function calls that begin with the first argument as well as the second argument. In case there are multiple calls with the same arity, the macro will try to disambiguate them by computing the corresponding guards that distinguish each call from the others. In the case of func2 , the expanded definitions would correspond to func2(arg2) func2(arg2, kwargs) , func2(arg2, arg3, kwargs) , func2(arg2, arg3, arg4) , func2(arg1, arg2) , func2(arg1, arg2, kwargs) , func2(arg1, arg2, arg3) , etc. Finally, if transforms are defined (like func3 ), they will be assigned to the specified arguments before calling the native function.","ref":"ExTorch.Native.Macros.html#defbindings/2","title":"ExTorch.Native.Macros.defbindings/2","type":"macro"},{"doc":"An ExTorch.Tensor is a multi-dimensional matrix containing elements of a single data type.","ref":"ExTorch.Tensor.html","title":"ExTorch.Tensor","type":"module"},{"doc":"Get the device of a tensor. Arguments tensor ( ExTorch.Tensor ): Input tensor","ref":"ExTorch.Tensor.html#device/1","title":"ExTorch.Tensor.device/1","type":"function"},{"doc":"Get the dtype of a tensor. Arguments tensor ( ExTorch.Tensor ): Input tensor","ref":"ExTorch.Tensor.html#dtype/1","title":"ExTorch.Tensor.dtype/1","type":"function"},{"doc":"Index a tensor using an accessor object. It acts as a alias for ExTorch.index/2 .","ref":"ExTorch.Tensor.html#fetch/2","title":"ExTorch.Tensor.fetch/2","type":"function"},{"doc":"Get a human readable representation of a tensor. Arguments tensor ( ExTorch.Tensor ): Input tensor","ref":"ExTorch.Tensor.html#repr/1","title":"ExTorch.Tensor.repr/1","type":"function"},{"doc":"Get the size of a tensor. Arguments tensor : Input tensor","ref":"ExTorch.Tensor.html#size/1","title":"ExTorch.Tensor.size/1","type":"function"},{"doc":"Convert a tensor into a list. Arguments tensor ( ExTorch.Tensor ): Input tensor","ref":"ExTorch.Tensor.html#to_list/1","title":"ExTorch.Tensor.to_list/1","type":"function"},{"doc":"An ExTorch.Tensor is a multi-dimensional matrix containing elements of a single data type.","ref":"ExTorch.Tensor.html#t:t/0","title":"ExTorch.Tensor.t/0","type":"type"},{"doc":"The ExTorch.Tensor.Options struct defines the creation parameters of a tensor.","ref":"ExTorch.Tensor.Options.html","title":"ExTorch.Tensor.Options","type":"module"},{"doc":"An ExTorch.Tensor.Options defines the creation parameters of a tensor.","ref":"ExTorch.Tensor.Options.html#t:t/0","title":"ExTorch.Tensor.Options.t/0","type":"type"},{"doc":"","ref":"ExTorch.Utils.html","title":"ExTorch.Utils","type":"module"},{"doc":"Given a list of elements or a list with lists with elements, this function returns a ExTorch.Utils.ListWrapper structure.","ref":"ExTorch.Utils.html#to_list_wrapper/1","title":"ExTorch.Utils.to_list_wrapper/1","type":"function"},{"doc":"Struct used to represent a list with elements or lists of elements.","ref":"ExTorch.Utils.ListWrapper.html","title":"ExTorch.Utils.ListWrapper","type":"module"},{"doc":"This struct wraps a list of elements or a list with lists of elements into a representation suitable to be converted into an ExTorch.Tensor","ref":"ExTorch.Utils.ListWrapper.html#t:t/0","title":"ExTorch.Utils.ListWrapper.t/0","type":"type"},{"doc":"General type hierarchy comparison utils","ref":"ExTorch.Utils.Types.html","title":"ExTorch.Utils.Types","type":"module"},{"doc":"Given a list/tuples with elements or lists/tuples of elements, determine the base type ExTorch.DType.base_type() that the list should have when converting it into a tensor.","ref":"ExTorch.Utils.Types.html#collect_types/2","title":"ExTorch.Utils.Types.collect_types/2","type":"function"},{"doc":"Given two basic types, compare them and return the type that subsumes the other one.","ref":"ExTorch.Utils.Types.html#compare_types/2","title":"ExTorch.Utils.Types.compare_types/2","type":"function"},{"doc":"","ref":"ExTorch.DelegateWithDocs.Error.html","title":"ExTorch.DelegateWithDocs.Error","type":"exception"}]